<?php
include("./include/config.php");

if (!isset($_SESSION['a_user'])) {
    header("Location: index.php");
    exit;
} else {
    include("./include/sidebar.php");

    $edit_id = isset($_GET['edit_id']) ? $_GET['edit_id'] : 0;
    $edit_mode = false;
    $existing_data = array();

    if ($edit_id) {
        $edit_query = "SELECT * FROM locality WHERE id = ?";
        $stmt = mysqli_prepare($conn, $edit_query);

        if ($stmt) {
            mysqli_stmt_bind_param($stmt, "i", $edit_id);
            mysqli_stmt_execute($stmt);

            $edit_result = mysqli_stmt_get_result($stmt);

            if (mysqli_num_rows($edit_result) == 1) {
                $edit_mode = true;
                $existing_data = mysqli_fetch_assoc($edit_result);
            } else {
                echo "Invalid edit ID.";
                exit;
            }

            mysqli_stmt_close($stmt);
        } else {
            echo "Prepared statement failed: " . mysqli_error($conn);
            exit;
        }
    }

    if (isset($_POST['update_location_btn'])) {
        $location_name = $_POST['location_name'];
        $city_id = $_POST['city_id'];
        $state_id = $_POST['state_id'];
        $meta_title = $_POST['meta_title'];
        $meta_keywords = $_POST['meta_keywords'];
        $meta_description = $_POST['meta_description'];
        
        function generateSlug($input) {
            // Convert the input to lowercase
            $slug = strtolower($input);
        
            // Replace spaces with hyphens
            $slug = str_replace(' ', '-', $slug);
        
            // Remove any special characters or non-alphanumeric characters
            $slug = preg_replace('/[^a-z0-9-]/', '', $slug);
        
            return $slug;
        }
        
       
        $slug = generateSlug($location_name);

        if ($edit_mode) {
            $update_query = "UPDATE locality SET
                location_name = ?,
                city_id = ?,
                state_id = ?,
                meta_title = ?,
                meta_keywords = ?,
                meta_description = ?,
                slug = ?
                WHERE id = ?";

            $stmt = mysqli_prepare($conn, $update_query);

            if ($stmt) {
                mysqli_stmt_bind_param($stmt, "siissssi", $location_name, $city_id, $state_id, $meta_title, $meta_keywords, $meta_description, $slug, $edit_id);
                mysqli_stmt_execute($stmt);

                if (mysqli_stmt_affected_rows($stmt) > 0) {
                    echo '<script>';
                    echo 'alert("Location updated successfully");';
                    echo 'window.location.href = "view_locality.php";';
                    echo '</script>';
                } else {
                    echo "Something went wrong: " . mysqli_error($conn);
                }

                mysqli_stmt_close($stmt);
            } else {
                echo "Prepared statement failed: " . mysqli_error($conn);
            }
        }
    }

?>


<div class="col-lg-12 col-xs-12">
    <div class="box-content card white">
        <h4 class="box-title">Edit Locality</h4>
        <div class="card-content">
            <form action="" method="POST" enctype="multipart/form-data">
                <div class="form-group col-lg-4">
                    <label for="exampleInputEmail1">State</label>
                    <select class="form-control" id="stateSelect" name="state_id">
                        <!--<option value="">Select a state</option>-->
                        <?php
                        // Query to fetch state names from the "states" table
                        $sql = "SELECT id, state_name FROM states";
                        $result = $conn->query($sql);

                        if ($result->num_rows > 0) {
                            while ($row = $result->fetch_assoc()) {
                                $stateId = $row['id'];
                                $stateName = $row['state_name'];

                                // Check if the current state is selected (based on $existing_data['state'])
                                $selected = ($stateId == $existing_data['state_id']) ? 'selected' : '';

                                // Output an <option> element for each state
                                echo "<option value='$stateId' $selected>$stateName</option>";
                            }
                        } else {
                            echo "<option value=''>No states found</option>";
                        }
                        ?>
                    </select>
                </div>
                                        <div class="form-group col-lg-4">
                                            <label for="exampleInputPassword1">City</label>
                                            <select class="form-control" id="citySelect" name="city_id">
                                                <!--<option value="">Select a state</option>-->
                                                <?php
                                                // Query to fetch state names from the "states" table
                                                $sql1 = "SELECT id, city_name FROM city";
                                                $result1 = $conn->query($sql1);
                        
                                                if ($result1->num_rows > 0) {
                                                    while ($row1 = $result1->fetch_assoc()) {
                                                        $cityId = $row1['id'];
                                                        $cityName = $row1['city_name'];
                        
                                                        // Check if the current state is selected (based on $existing_data['state'])
                                                        $selected1 = ($cityId == $existing_data['city_id']) ? 'selected' : '';
                        
                                                        // Output an <option> element for each state
                                                        echo "<option value='$cityId' $selected1>$cityName</option>";
                                                    }
                                                } 
                                                // else {
                                                //     echo "<option value=''>No states found</option>";
                                                // }
                                                ?>
                                                <option value="">Select a city</option>
                                            </select>
                                        </div>
                <div class="form-group col-lg-4">
                    <label for="exampleInputPassword1">Edit Location</label>
                    <input type="text" class="form-control" id="exampleInputPassword1" name="location_name" value="<?= $existing_data['location_name']; ?>" placeholder="Enter City">
                </div>
                <div class="form-group col-lg-6">
                    <label for="categorySelect">Meta Title</label>
                    <input class="form-control" name="meta_title" type="text" value="<?= $existing_data['meta_title']; ?>" placeholder="Enter meta title ....">
                  
                </div>
                <div class="form-group col-lg-6">
                    <label for="categorySelect">Meta Keywords</label>
                    <input class="form-control" name="meta_keywords" type="text" value="<?= $existing_data['meta_keywords']; ?>" placeholder="Enter meta keywords...">
                  
                </div>
                <div class="form-group col-lg-12">
                    <label for="categorySelect">Meta Description</label>
                    <!--<input class="form-control" name="category_name" type="text">-->
                    <textarea class="form-control" name="meta_description" type="text" placeholder="Enter meta description...."><?= $existing_data['meta_description']; ?></textarea>
                  
                </div>
                <!--<div class="form-group col-lg-12">-->
                <!--    <label for="categorySelect">Page Content</label>-->
                    <!--<input class="form-control" name="category_name" type="text">-->
                <!--    <textarea class="form-control" name="page_content" type="text" placeholder="Enter page content ...."></textarea>-->
                  
                <!--</div>-->
                <button type="submit" name="update_location_btn" class="btn btn-primary btn-sm waves-effect waves-light">Update</button>
            </form>
        </div>
    </div>
</div>


<!-- Include jQuery library -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<script>
document.addEventListener("DOMContentLoaded", function () {
    const stateSelect = document.getElementById("stateSelect");
    const citySelect = document.getElementById("citySelect");
    const existingCityId = <?php echo $existing_data['city_id']; ?>; // Get the existing city ID from PHP

    // Add an event listener to the state select element
    stateSelect.addEventListener("change", function () {
        const selectedStateId = stateSelect.value;

        // Clear the city options
        citySelect.innerHTML = "<option value=''>Select a city</option>";

        if (selectedStateId !== "") {
            // Use AJAX to fetch city data based on the selected state
            // Replace 'get_cities.php' with the URL of your server-side script
            fetch(`get_cities.php?state_id=${selectedStateId}`)
                .then((response) => response.json())
                .then((data) => {
                    data.forEach((city) => {
                        const option = document.createElement("option");
                        option.value = city.id;
                        option.textContent = city.city_name;
                        citySelect.appendChild(option);
                    });

                    // Select the existing city if it matches one of the fetched options
                    if (existingCityId !== "") {
                        const existingOption = citySelect.querySelector(`option[value='${existingCityId}']`);
                        if (existingOption) {
                            existingOption.selected = true;
                        }
                    }
                })
                .catch((error) => console.error(error));
        }
    });

    // Trigger the state select change event to populate the city options initially
    stateSelect.dispatchEvent(new Event("change"));
});
</script>
<script>
    CKEDITOR.replace( 'page_content' );
CKEDITOR.on( 'instanceReady', function( evt )
  {
    var editor = evt.editor;
   
   editor.on('change', function (e) { 
    var contentSpace = editor.ui.space('contents');
    var ckeditorFrameCollection = contentSpace.$.getElementsByTagName('iframe');
    var ckeditorFrame = ckeditorFrameCollection[0];
    var innerDoc = ckeditorFrame.contentDocument;
    var innerDocTextAreaHeight = $(innerDoc.body).height();
    console.log(innerDocTextAreaHeight);
    });
 });

</script>

    <?php

}

include("./include/footer.php");

?>
