<?php
include("./include/config.php");

// Ensure session is started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

if (!isset($_SESSION['a_user'])) {
    header("Location: index.php");
    exit();
} else {
    include("./include/sidebar.php");

    // Fetch cities from database
    $query = "SELECT `id`, `city_name` FROM `city`";
    $result = mysqli_query($conn, $query);

    // Check if query executed successfully
    if ($result) {
        $cities = mysqli_fetch_all($result, MYSQLI_ASSOC);
    } else {
        echo "Error fetching cities: " . mysqli_error($conn);
        $cities = []; // Empty array if query fails
    }

    if (isset($_POST['add_numbers_btn'])) {
        $city_id = $_POST['city_id']; // Assuming you have a city_id input
        $whatsapp_numbers = $_POST['whatsapp_numbers'];
        $contact_numbers = $_POST['contact_numbers'];
        
        // Split comma-separated numbers into arrays
        $whatsapp_numbers_array = explode(',', $whatsapp_numbers);
        $contact_numbers_array = explode(',', $contact_numbers);
        
        // Validate input arrays
        if (count($whatsapp_numbers_array) != count($contact_numbers_array)) {
            echo "Number of WhatsApp numbers must match number of contact numbers.";
            exit();
        }

        // Fetch ads IDs for the selected city
        $query_ads_ids = "SELECT `id` FROM `ads` WHERE `city_id` = $city_id";
        $result_ads_ids = mysqli_query($conn, $query_ads_ids);

        if ($result_ads_ids) {
            $ads_ids = mysqli_fetch_all($result_ads_ids, MYSQLI_ASSOC);
        } else {
            echo "Error fetching ads IDs: " . mysqli_error($conn);
            exit();
        }

        // Loop through each ad and update WhatsApp and contact numbers
        $index = 0; // Index to iterate through input arrays
        foreach ($ads_ids as $ad) {
            $ad_id = $ad['id'];
            $whatsapp_number = mysqli_real_escape_string($conn, trim($whatsapp_numbers_array[$index % count($whatsapp_numbers_array)]));
            $contact_number = mysqli_real_escape_string($conn, trim($contact_numbers_array[$index % count($contact_numbers_array)]));
            
            // Update query for each ad
            $query = "UPDATE ads 
                      SET whatsapp_number = '$whatsapp_number', 
                          contact_number = '$contact_number'
                      WHERE city_id = $city_id
                      AND id = $ad_id";

            $query_run = mysqli_query($conn, $query);

            if (!$query_run) {
                echo "Error updating ad $ad_id: " . mysqli_error($conn);
                break; // Exit loop on error
            }

            // Increment index for next ad
            $index++;
        }

        // Redirect after updating all ads
        if ($query_run) {
            echo '<script>';
            echo 'alert("Numbers added successfully");';
            // echo 'window.location.href = "add_numbers.php";';
            echo '</script>';
        } else {
            echo "Something went wrong with updating ads.";
        }
    }
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Numbers</title>
    <!-- Include your CSS files here -->
</head>
<body>
    <div class="col-lg-12 col-xs-12">
        <div class="box-content card white">
            <h4 class="box-title">Add Numbers</h4>
            <div class="card-content">
                <form action="" method="POST" enctype="multipart/form-data">
                    <div class="form-group col-lg-6">
                        <label for="city_id">Select City</label>
                        <select class="form-control" id="city_id" name="city_id" required>
                            <option value="">Select City</option>
                            <?php foreach ($cities as $city): ?>
                                <option value="<?php echo $city['id']; ?>"><?php echo $city['city_name']; ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group col-lg-12">
                        <label for="whatsapp_numbers">WhatsApp Numbers (comma-separated)</label><br>
                        <input type="text" class="form-control" id="whatsapp_numbers" name="whatsapp_numbers" placeholder="Enter WhatsApp Numbers" required><br>
                    </div>
                    <div class="form-group col-lg-12">
                        <label for="contact_numbers">Contact Numbers (comma-separated)</label><br>
                        <input type="text" class="form-control" id="contact_numbers" name="contact_numbers" placeholder="Enter Contact Numbers" required><br>
                    </div>
                    <div class="form-group col-lg-12">
                        <button type="submit" name="add_numbers_btn" class="btn btn-primary btn-sm waves-effect waves-light">Add Numbers</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <!-- Include your JS files here -->
</body>
</html>

<?php
include("./include/footer.php");
?>
