<?php

function generate_sitemap($url, $output_file = "sitemap.xml") {
    // Parse the base URL
    $parsed_url = parse_url($url);
    $base_url = $parsed_url['scheme'] . '://' . $parsed_url['host'];

    // Create a SimpleXMLElement object
    $xml = new SimpleXMLElement('<?xml version="1.0" encoding="UTF-8"?><urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9"></urlset>');

    // Start crawling from the initial URL
    crawl_page($url, $base_url, $xml);

    // Save the XML to the sitemap.xml file
    $xml->asXML($output_file);
}

function crawl_page($url, $base_url, $xml) {
    // Send a GET request to the page
    $response = file_get_contents($url);

    // Check if the request was successful
    if ($response !== false) {
        // Parse the HTML content of the page
        $dom = new DOMDocument;
        libxml_use_internal_errors(true); // Enable libxml errors handling
        @$dom->loadHTML($response);
        libxml_clear_errors(); // Clear libxml errors

        if ($dom) {
            // Find all anchor tags (links) on the page
            $links = $dom->getElementsByTagName('a');

            // Add each URL within the specified domain to the XML structure
            foreach ($links as $link) {
                $href = $link->getAttribute('href');
                if ($href) {
                    $abs_url = resolve_url($base_url, $href);
                    if (strpos($abs_url, $base_url) === 0) {
                        $urlElement = $xml->addChild('url');
                        $urlElement->addChild('loc', htmlspecialchars($abs_url));

                        // Recursively crawl the linked page
                        crawl_page($abs_url, $base_url, $urlElement);
                    }
                }
            }
        } else {
            echo "Error parsing HTML for URL: $url\n";
        }
    } else {
        echo "Error fetching URL: $url\n";
    }
}

// Function to resolve relative URLs
function resolve_url($base, $relative) {
    $parts = array_merge(parse_url($base), parse_url($relative));
    $path = [];
    if (!empty($parts['path'])) {
        $path = explode('/', $parts['path']);
    }
    $new_path = [];
    foreach ($path as $segment) {
        if ($segment === '..') {
            array_pop($new_path);
        } elseif ($segment !== '.') {
            $new_path[] = $segment;
        }
    }
    $parts['path'] = implode('/', $new_path);
    return $parts['scheme'] . '://' . $parts['host'] . $parts['path'];
}

// Example usage
generate_sitemap('https://www.liptkal.com');
